==> am_mod_lbr_0_2.zip: am_module_library/components/lbr/language/1/barnraiser_01/page.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once('inc/lbr_common.inc.php');

// HEADER
$lang['hdr_tags'] = 							"tags";
$lang['hdr_my_participation'] = 				"my participation";
$lang['hdr_wiki_set'] = 						"wiki-set";
$lang['hdr_wiki_page'] = 						"wiki page";
$lang['hdr_latest_revisions'] = 				"latest revisions";


// SUB
$lang['sub_tag_ok'] = 							"OK";
$lang['sub_tag_delete'] = 						"DEL";


//A HREF TAGS (links)
$lang['href_edit_page'] = 						"revise this page";
$lang['href_respect'] = 						"respect";


// ERROR
//$lang['err_no_items'] = 						"Sorry, there are no wiki pages available.";


// BODY
$lang['txt_role'] = 							"role";
$lang['txt_status']	=							"status";
$lang['txt_bookmarked'] = 						"bookmarked in this set";
$lang['txt_relevent_summary'] = 				"SYS_KEYWORD_PERCENTAGE% of people who have voted think this item is relevent";
$lang['txt_accurate_summary'] = 				"SYS_KEYWORD_PERCENTAGE% of people who have voted think this item is accurate";
$lang['txt_tags'] = 							"tags";
$lang['txt_participate_first'] = 				"you need to participate in order to leave comments";
$lang['txt_alt_remove_bookmark'] = 				"remove bookmark";
$lang['txt_title_remove_bookmark'] = 			"remove bookmark from this page";
$lang['txt_alt_bookmark'] = 					"bookmark";
$lang['txt_title_bookmark'] = 					"bookmark this page";
$lang['txt_alt_track'] = 						"track";
$lang['txt_title_track'] = 						"track this page";
$lang['txt_alt_remove_recommendation'] = 		"remove recommendation";
$lang['txt_title_remove_recommendation'] = 		"remove recommendation from this page";
$lang['txt_alt_add_recommendation'] = 			"recommend";
$lang['txt_title_add_recommendation'] = 		"recommend this page";
$lang['txt_relevent'] = 						"relevent?";
$lang['txt_accurate'] = 						"accurate?";
$lang['txt_wiki_name'] = 						"wiki name";

$lang['txt_title_not_relevent'] = 				"you have voted this page as not relevent";
$lang['txt_title_set_not_relevent'] = 			"this page is not relevent";
$lang['txt_alt_not_relevent'] = 				"not relevent";
$lang['txt_title_relevent'] = 					"you have voted this page as relevent";
$lang['txt_title_set_relevent'] = 				"this page is relevent";
$lang['txt_alt_relevent'] = 					"relevent";

$lang['txt_title_not_accurate'] = 				"you have voted this page as not accurate";
$lang['txt_title_set_not_accurate'] = 			"this page is not accurate";
$lang['txt_alt_not_accurate'] = 				"not accurate";
$lang['txt_title_accurate'] = 					"you have voted this page as accurate";
$lang['txt_title_set_accurate'] = 				"this page is accurate";
$lang['txt_alt_accurate'] = 					"accurate";

?>

==> am_mod_lbr_0_4.zip: am_module_library/components/lbr/language/1/barnraiser_01/page.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once('inc/lbr_common.inc.php');

// HEADER
$lang['hdr_tags'] = 							"tags";
$lang['hdr_my_participation'] = 				"my participation";
$lang['hdr_wiki_set'] = 						"wiki-set";
$lang['hdr_wiki_page'] = 						"wiki page";
$lang['hdr_latest_revisions'] = 				"latest revisions";


// SUB
$lang['sub_tag_ok'] = 							"OK";
$lang['sub_tag_delete'] = 						"DEL";


//A HREF TAGS (links)
$lang['href_edit_page'] = 						"revise this page";
$lang['href_respect'] = 						"respect";


// ERROR
//$lang['err_no_items'] = 						"Sorry, there are no wiki pages available.";


// BODY
$lang['txt_role'] = 							"role";
$lang['txt_status']	=							"status";
$lang['txt_bookmarked'] = 						"bookmarked in this set";
$lang['txt_relevent_summary'] = 				"SYS_KEYWORD_PERCENTAGE% of people who have voted think this item is relevent";
$lang['txt_accurate_summary'] = 				"SYS_KEYWORD_PERCENTAGE% of people who have voted think this item is accurate";
$lang['txt_tags'] = 							"tags";
$lang['txt_participate_first'] = 				"you need to participate in order to leave comments";
$lang['txt_alt_remove_bookmark'] = 				"remove bookmark";
$lang['txt_title_remove_bookmark'] = 			"remove bookmark from this page";
$lang['txt_alt_add_bookmark'] = 					"bookmark";
$lang['txt_title_add_bookmark'] = 					"bookmark this page";
$lang['txt_alt_add_track'] = 						"track";
$lang['txt_title_add_track'] = 						"track this page";
$lang['txt_alt_remove_recommendation'] = 		"remove recommendation";
$lang['txt_title_remove_recommendation'] = 		"remove recommendation from this page";
$lang['txt_alt_add_recommendation'] = 			"recommend";
$lang['txt_title_add_recommendation'] = 		"recommend this page";
$lang['txt_relevent'] = 						"relevent?";
$lang['txt_accurate'] = 						"accurate?";
$lang['txt_wiki_name'] = 						"wiki name";

$lang['txt_title_not_relevent'] = 				"you have voted this page as not relevent";
$lang['txt_title_set_not_relevent'] = 			"this page is not relevent";
$lang['txt_alt_not_relevent'] = 				"not relevent";
$lang['txt_title_relevent'] = 					"you have voted this page as relevent";
$lang['txt_title_set_relevent'] = 				"this page is relevent";
$lang['txt_alt_relevent'] = 					"relevent";

$lang['txt_title_not_accurate'] = 				"you have voted this page as not accurate";
$lang['txt_title_set_not_accurate'] = 			"this page is not accurate";
$lang['txt_alt_not_accurate'] = 				"not accurate";
$lang['txt_title_accurate'] = 					"you have voted this page as accurate";
$lang['txt_title_set_accurate'] = 				"this page is accurate";
$lang['txt_alt_accurate'] = 					"accurate";

?>
